powered by
Quantiles of the fiducial distribution of a parameter of interest.
gfiQuantile(parameter, fidsamples, probs)
Numeric vector of quantiles, of the same length as probs.
probs
a right-sided formula defining the parameter of interest
fiducial samples, the output of gfilogisreg
gfilogisreg
numeric vector of probabilities
y <- c( 0, 0, 0, 1, 0, 1, 1, 1 ) group <- gl(2, 4) fidsamples <- gfilogisreg(y ~ 0 + group, N = 500) # (N=500 is not serious) gfiQuantile(~ group2 - group1, fidsamples, c(25, 50, 75)/100)
Run the code above in your browser using DataLab